@@ -1,14 +1,14 @@
 #!/bin/sh
 
 # compile_cdrskin.sh  
-# Copyright 2005 - 2021 Thomas Schmitt, scdbackup@gmx.net, GPL v2 or later
+# Copyright 2005 - 2023 Thomas Schmitt, scdbackup@gmx.net, GPL v2 or later
 # to be executed within  ./libburn-*  or./cdrskin-*
 
 debug_opts="-O2"
 def_opts=
 largefile_opts="-D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE=1"
 fifo_opts=""
-libvers="-DCdrskin_libburn_1_5_4"
+libvers="-DCdrskin_libburn_1_5_6"
 
 # To be used if Makefile.am uses libburn_libburn_la_CFLAGS
 # burn="libburn/libburn_libburn_la-"
@@ -41,15 +41,15 @@ do
   elif test "$i" = "-compile_dewav"
   then
     compile_dewav=1
-  elif test "$i" = "-libburn_1_5_4"
+  elif test "$i" = "-libburn_1_5_6"
   then
-    libvers="-DCdrskin_libburn_1_5_4"
+    libvers="-DCdrskin_libburn_1_5_6"
     libdax_audioxtr_o="$burn"libdax_audioxtr.o
     libdax_msgs_o="$burn"libdax_msgs.o
     cleanup_src_or_obj="$burn"cleanup.o
   elif test "$i" = "-libburn_svn"
   then
-    libvers="-DCdrskin_libburn_1_5_5"
+    libvers="-DCdrskin_libburn_1_5_7"
     libdax_audioxtr_o="$burn"libdax_audioxtr.o
     libdax_msgs_o="$burn"libdax_msgs.o
     cleanup_src_or_obj="$burn"cleanup.o
@@ -99,8 +99,8 @@ do
     echo "Options:"
     echo "  -compile_cdrfifo  compile program cdrskin/cdrfifo."
     echo "  -compile_dewav    compile program test/dewav without libburn."
-    echo "  -libburn_1_5_2    set macro to match libburn-1.5.2"
-    echo "  -libburn_svn      set macro to match current libburn-SVN."
+    echo "  -libburn_1_5_6    set macro to match libburn-1.5.6"
+    echo "  -libburn_svn      set macro to match current libburn git."
     echo "  -dvd_obs_64k      64 KB default size for DVD/BD writing."
     echo "  -use_libcdio      link with -lcdio because libburn uses it."
     echo "  -do_not_compile_cdrskin  omit compilation of cdrskin/cdrskin."
