@@ -55,6 +55,7 @@ struct burn_write_opts *burn_write_opts_new(struct burn_drive *drive)
 	opts->obs_pad = 0;
 #endif
 
+	opts->bdr_obs_exempt = 0;
 	opts->start_byte = -1;
 	opts->fill_up_media = 0;
 	opts->force_is_set = 0;
@@ -535,17 +536,25 @@ void burn_write_opts_set_obs_pad(struct burn_write_opts *opts, int pad)
 }
 
 
-/* ts A91115: API */
-void burn_write_opts_set_stdio_fsync(struct burn_write_opts *opts, int rythm)
+/* ts C10909: API */
+void burn_write_opts_set_bdr_obs_exempt(struct burn_write_opts *opts,
+					int value)
 {
-	if (rythm == -1)
+	opts->bdr_obs_exempt = !!value;
+}
+
+
+/* ts A91115: API */
+void burn_write_opts_set_stdio_fsync(struct burn_write_opts *opts, int rhythm)
+{
+	if (rhythm == -1)
 		opts->stdio_fsync_size = -1; /* never */
-	else if (rythm == 0)
+	else if (rhythm == 0)
 		opts->stdio_fsync_size = Libburn_stdio_fsync_limiT;
-	else if (rythm == 1)
+	else if (rhythm == 1)
 		opts->stdio_fsync_size = 0; /* only at end of writing */
-	else if (rythm >= 32)
-		opts->stdio_fsync_size = rythm;
+	else if (rhythm >= 32)
+		opts->stdio_fsync_size = rhythm;
 }
 
 
