@@ -2,9 +2,10 @@
 /* os-linux.h
    Operating system specific libburn definitions and declarations. Included
    by os.h in case of compilation for
-           Linux kernels 2.4 and 2.6 with Linux SCSI Generic (sg)
+           Linux kernels 2.4 and 2.6, GNU/Linux SCSI Generic (sg)
 
-   Copyright (C) 2006 Thomas Schmitt <scdbackup@gmx.net>, provided under GPL
+   Copyright (C) 2006 - 2013 Thomas Schmitt <scdbackup@gmx.net>
+   Provided under GPL version 2 or later.
 */
 
 
@@ -15,29 +16,27 @@
 #define BURN_OS_SIGNAL_MACRO_LIST \
  SIGHUP, SIGINT, SIGQUIT, SIGILL, SIGABRT, \
  SIGFPE, SIGSEGV, SIGPIPE, SIGALRM, SIGTERM, \
- SIGUSR1, SIGUSR2, SIGXCPU, SIGTSTP, SIGTTIN, \
- SIGTTOU, \
- SIGBUS, SIGPOLL, SIGPROF, SIGSYS, SIGTRAP, \
- SIGVTALRM, SIGXCPU, SIGXFSZ
+ SIGUSR1, SIGUSR2, SIGXCPU, SIGBUS, SIGPOLL, \
+ SIGPROF, SIGSYS, SIGTRAP, SIGVTALRM, SIGXCPU, \
+ SIGXFSZ
 
 /* Once as text 1:1 list of strings for messages and interpreters */
 #define BURN_OS_SIGNAL_NAME_LIST \
  "SIGHUP", "SIGINT", "SIGQUIT", "SIGILL", "SIGABRT", \
  "SIGFPE", "SIGSEGV", "SIGPIPE", "SIGALRM", "SIGTERM", \
- "SIGUSR1", "SIGUSR2", "SIGXCPU", "SIGTSTP", "SIGTTIN", \
- "SIGTTOU", \
- "SIGBUS", "SIGPOLL", "SIGPROF", "SIGSYS", "SIGTRAP", \
- "SIGVTALRM", "SIGXCPU", "SIGXFSZ"
+ "SIGUSR1", "SIGUSR2", "SIGXCPU", "SIGBUS", "SIGPOLL", \
+ "SIGPROF", "SIGSYS", "SIGTRAP", "SIGVTALRM", "SIGXCPU", \
+ "SIGXFSZ"
 
 /* The number of above list items */
-#define BURN_OS_SIGNAL_COUNT 24
+#define BURN_OS_SIGNAL_COUNT 21
 
 /** To list all signals which shall surely not be caught */
 #define BURN_OS_NON_SIGNAL_MACRO_LIST \
-SIGKILL, SIGCHLD, SIGSTOP, SIGURG, SIGWINCH
+SIGKILL, SIGCHLD, SIGSTOP, SIGTSTP, SIGCONT, SIGURG, SIGWINCH, SIGTTIN, SIGTTOU
 
 /* The number of above list items */
-#define BURN_OS_NON_SIGNAL_COUNT 5
+#define BURN_OS_NON_SIGNAL_COUNT 9
 
 
 /* The maximum size for a (SCSI) i/o transaction */
@@ -51,11 +50,17 @@ SIGKILL, SIGCHLD, SIGSTOP, SIGURG, SIGWINCH
 #define BURN_OS_TRANSPORT_BUFFER_SIZE 65536
 
 
-/* To hold the index number of the most recently delivered address from
+/* To hold the position of the most recently delivered address from
    device enumeration.
 */
+struct burn_drive_enumerator_struct {
+	int pos;
+	int info_count;
+	char **info_list;
+};
+
 #define BURN_OS_DEFINE_DRIVE_ENUMERATOR_T \
-typedef int burn_drive_enumerator_t;
+typedef struct burn_drive_enumerator_struct burn_drive_enumerator_t;
 
 
 /* Parameters for sibling list. See sibling_fds, sibling_fnames */
